@@ -1,10 +1,11 @@
 '''
 # GitHub Self-Hosted Runners CDK Constructs
 
-[![NPM](https://img.shields.io/npm/v/@cloudsnorkel/cdk-github-runners?label=npm+cdk&logo=npm)](https://www.npmjs.com/package/@cloudsnorkel/cdk-github-runners)
-[![PyPI](https://img.shields.io/pypi/v/@cloudsnorkel/cdk-github-runners?label=pypi+cdk&logo=pypi)](https://pypi.org/project/cloudsnorkel.cdk-github-runners)
+[![NPM](https://img.shields.io/npm/v/@cloudsnorkel/cdk-github-runners?label=npm&logo=npm)](https://www.npmjs.com/package/@cloudsnorkel/cdk-github-runners)
+[![PyPI](https://img.shields.io/pypi/v/cloudsnorkel.cdk-github-runners?label=pypi&logo=pypi)](https://pypi.org/project/cloudsnorkel.cdk-github-runners)
 [![Maven Central](https://img.shields.io/maven-central/v/com.cloudsndorkel/cdk.github.runners.svg?label=Maven%20Central&logo=java)](https://search.maven.org/search?q=g:%22com.cloudnsorkel%22%20AND%20a:%22cdk.github.runners%22)
-[![Go](https://img.shields.io/github/v/tag/CloudSnorkel/cdk-github-runners?color=red&label=go&logo=go)](https://github.com/CloudSnorkel/cdk-github-runners-go/tree/main/cloudsnorkelcdkgithubrunners)
+[![Go](https://img.shields.io/github/v/tag/CloudSnorkel/cdk-github-runners?color=red&label=go&logo=go)](https://pkg.go.dev/github.com/CloudSnorkel/cdk-github-runners-go/cloudsnorkelcdkgithubrunners)
+[![Nuget](https://img.shields.io/nuget/v/CloudSnorkel.Cdk.Github.Runners?color=red&&logo=nuget)](https://www.nuget.org/packages/CloudSnorkel.Cdk.Github.Runners/)
 [![Release](https://github.com/CloudSnorkel/cdk-github-runners/actions/workflows/release.yml/badge.svg)](https://github.com/CloudSnorkel/cdk-github-runners/actions/workflows/release.yml)
 [![License](https://img.shields.io/badge/license-Apache--2.0-blue)](https://github.com/CloudSnorkel/cdk-github-runners/blob/main/LICENSE)
 
@@ -45,9 +46,33 @@ You can also create your own provider by implementing [`IRunnerProvider`](API.md
 2. Install the appropriate package
 
    1. [Python](https://www.npmjs.com/package/@cloudsnorkel/cdk-github-runners)
+
+      ```
+      pip install cloudsnorkel.cdk-github-runners
+      ```
    2. [TypeScript or JavaScript](https://pypi.org/project/cloudsnorkel.cdk-github-runners)
+
+      ```
+      npm i @cloudsnorkel/cdk-github-runners
+      ```
    3. [Java](https://search.maven.org/search?q=g:%22com.cloudnsorkel%22%20AND%20a:%22cdk.github.runners%22)
-   4. [Go](https://github.com/CloudSnorkel/cdk-github-runners-go/tree/main/cloudsnorkelcdkgithubrunners)
+
+      ```xml
+      <dependency>
+      <groupId>com.cloudsnorkel</groupId>
+      <artifactId>cdk.github.runners</artifactId>
+      </dependency>
+      ```
+   4. [Go](https://pkg.go.dev/github.com/CloudSnorkel/cdk-github-runners-go/cloudsnorkelcdkgithubrunners)
+
+      ```
+      go get github.com/CloudSnorkel/cdk-github-runners-go/cloudsnorkelcdkgithubrunners
+      ```
+   5. [.NET](https://www.nuget.org/packages/CloudSnorkel.Cdk.Github.Runners/)
+
+      ```
+      dotnet add package CloudSnorkel.Cdk.Github.Runners
+      ```
 3. Use [`GitHubRunners`](API.md#CodeBuildRunner) construct in your code (starting with defaults is fine)
 4. Deploy your stack
 5. Look for the status command output similar to `aws --region us-east-1 lambda invoke --function-name status-XYZ123 status.json`
